import 'bootstrap-datepicker';
import { Component, forwardRef, Input, ViewChild, NgModule } from '@angular/core';
import { NG_VALUE_ACCESSOR } from '@angular/forms';
import { CommonModule } from '@angular/common';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
const BASE_OPTION = /** @type {?} */ ({
    autoclose: true,
    format: 'dd/mm/yyyy',
    language: 'en-GB'
});
const th_TH = /** @type {?} */ (Object.assign({}, BASE_OPTION, { language: 'th-TH' }));
const en_GB = /** @type {?} */ (Object.assign({}, BASE_OPTION, { language: 'en-GB' }));
const NGQ_DATETIME_VALUE_ACCESSOR = {
    provide: NG_VALUE_ACCESSOR,
    useExisting: forwardRef(() => NgqDatepickerComponent),
    multi: true
};
class NgqDatepickerComponent {
    constructor() {
        this.propagateChange = _ => { };
    }
    /**
     * @param {?} opts
     * @return {?}
     */
    set opts(opts) {
        this._opts = opts;
        if (this._jQueryElement) {
            this._jQueryElement.datepicker('destroy');
            const /** @type {?} */ newVal = !!this._value
                ? new Intl.DateTimeFormat(this._opts.language).format(this._value)
                : '';
            this._jQueryElement.val(newVal);
            this.initDatepicker();
        }
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        this._jQueryElement = jQuery(this.input.nativeElement);
        this.initDatepicker();
    }
    /**
     * @return {?}
     */
    initDatepicker() {
        this._opts = this._opts ? this._opts : th_TH;
        this._jQueryElement.datepicker(this._opts);
        this._jQueryElement.datepicker().on('changeDate', (e) => {
            this._value = e.date;
            this.propagateChange(this._value);
        });
        this._jQueryElement.datepicker('update', this._value);
        this._jQueryElement.prop('disabled', this._isDisabled);
    }
    /**
     * @param {?} value
     * @return {?}
     */
    onChange(value) {
        if (!value) {
            this._value = null;
            this.propagateChange(this._value);
        }
        else {
            if (this._jQueryElement) {
                this._jQueryElement.datepicker('destroy');
                this.initDatepicker();
            }
        }
    }
    /**
     * @param {?} obj
     * @return {?}
     */
    writeValue(obj) {
        this._value = obj;
        if (this._jQueryElement) {
            this._jQueryElement.datepicker('update', this._value);
        }
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnChange(fn) {
        this.propagateChange = fn;
    }
    /**
     * @param {?} fn
     * @return {?}
     */
    registerOnTouched(fn) { }
    /**
     * @param {?} isDisabled
     * @return {?}
     */
    setDisabledState(isDisabled) {
        this._isDisabled = isDisabled;
        if (this._jQueryElement) {
            this._jQueryElement.prop('disabled', this._isDisabled);
        }
    }
}
NgqDatepickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'ngq-datepicker',
                template: `<div *ngIf="!hideIcon" class="input-group">
  <input #input type="text" [attr.class]="class" [attr.id]="id" [attr.placeholder]="placeholder" (change)="onChange($event.target.value)">
  <div class="input-group-addon" (click)="_jQueryElement.datepicker('show')">
    <span class="glyphicon glyphicon-calendar"></span>
  </div>
</div>
<input *ngIf="hideIcon" #input type="text" [attr.class]="class" [attr.id]="id" [attr.placeholder]="placeholder" (change)="onChange($event.target.value)">
`,
                styles: [`:host{outline:0}`],
                providers: [NGQ_DATETIME_VALUE_ACCESSOR]
            },] },
];
/** @nocollapse */
NgqDatepickerComponent.ctorParameters = () => [];
NgqDatepickerComponent.propDecorators = {
    "hideIcon": [{ type: Input },],
    "id": [{ type: Input },],
    "class": [{ type: Input },],
    "placeholder": [{ type: Input },],
    "input": [{ type: ViewChild, args: ['input',] },],
    "opts": [{ type: Input, args: ['opts',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class NgqDatepickerModule {
}
NgqDatepickerModule.decorators = [
    { type: NgModule, args: [{
                imports: [CommonModule],
                declarations: [NgqDatepickerComponent],
                exports: [NgqDatepickerComponent]
            },] },
];
/** @nocollapse */
NgqDatepickerModule.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { BASE_OPTION, th_TH, en_GB, NgqDatepickerComponent, NgqDatepickerModule };
//# sourceMappingURL=ngq-datepicker.js.map
